starcluster.webtools.BaseHandler

Package starcluster :: Module webtools :: Class BaseHandler |
[hide private]
[frames] | no frames]

# Class BaseHandler

source code

Nested Classes | [hide private]
Inherited from `BaseHTTPServer.BaseHTTPRequestHandler`: `MessageClass`

Instance Methods | [hide private]
do_GET(self) | source code
do_POST(self) | source code
do_shutdown(self) | source code
Inherited from `BaseHTTPServer.BaseHTTPRequestHandler`: `address_string`, `date_time_string`, `end_headers`, `handle`, `handle_one_request`, `log_date_time_string`, `log_error`, `log_message`, `log_request`, `parse_request`, `send_error`, `send_header`, `send_response`, `version_string` Inherited from `SocketServer.StreamRequestHandler`: `finish`, `setup` Inherited from `SocketServer.BaseRequestHandler`: `__init__`

Class Variables | [hide private]
| error_message_format = ``'``<head>\n<title>DOH!</title>\n</head>\n``...``
Inherited from `BaseHTTPServer.BaseHTTPRequestHandler`: `default_request_version`, `error_content_type`, `monthname`, `protocol_version`, `responses`, `server_version`, `sys_version`, `weekdayname` Inherited from `SocketServer.StreamRequestHandler`: `rbufsize`, `wbufsize`

Class Variable Details | [hide private]

  ### error_message_format Value:
      '''<head>
      <title>DOH!</title>
      </head>
      <body>
      <pre>
       _  _    ___  _  _
      | || |  / _ \\| || |
      | || |_| | | | || |_
      ...